package com.hzya.frame.plugin.lets.util;

import cn.hutool.core.lang.Assert;
import com.alibaba.fastjson.JSON;
import com.hzya.frame.plugin.lets.ofsvo.QueryOfsSoSaleOutVo;
import com.hzya.frame.ttxofs.dto.InterfaceParamDto;
import com.hzya.frame.ttxofs.dto.ofspurchasereturnorder.PurchaseReturnOrder;
import com.hzya.frame.ttxofs.dto.ofspurchasereturnorder.PurchaseReturnOrderBean;
import com.hzya.frame.ttxofs.dto.ofssaleorderoutsearch.HeaderDetailsDto;
import com.hzya.frame.ttxofs.dto.ofssaleorderoutsearch.SaleOutReturnMessageDto;
import com.hzya.frame.ttxofs.dto.stock.StockinOrderSearchResponse;
import com.hzya.frame.ttxofs.service.OfsUnifiedService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * OFS标准接口查询，业务区分类
 *
 * @Author：liuyang
 * @Package：com.hzya.frame.plugin.lets.util
 * @Project：kangarooDataCenterV3
 * @name：OfsStandardUtil
 * @Date：2024/8/22 13:30
 * @Filename：OfsStandardUtil
 */
@Component
public class OfsStandardUtil {

    Logger logger = LoggerFactory.getLogger(OfsStandardUtil.class);

    @Autowired
    private OfsUnifiedService ofsUnifiedService;

    /**
     * OFS出库单查询
     *
     * @param queryOfsSoSaleOutVo  接口查询入参
     * @param headerDetailsDtoList 收集对象
     * @param pageNo               从第几页开始查询
     * @param api                  api接口名称
     * @author liuyang
     */
    public void queryOfsSaleOrder(QueryOfsSoSaleOutVo queryOfsSoSaleOutVo, List<HeaderDetailsDto> headerDetailsDtoList, Long pageNo, String api) throws Exception {
        Assert.notNull(queryOfsSoSaleOutVo, "queryOfsSoSaleOutVo不能为空！");
        Assert.notNull(headerDetailsDtoList, "headerDetailsDtoList不能为空");
        Assert.notNull(pageNo, "pageNo不能为空");
        Assert.notNull(api, "api不能为空");

        Long pageSize = 200L;
        queryOfsSoSaleOutVo.setPageNo(pageNo);
        queryOfsSoSaleOutVo.setPageSize(pageSize);

        InterfaceParamDto interfaceParamDto = new InterfaceParamDto();
        interfaceParamDto.setApi(api);
        interfaceParamDto.setData(JSON.toJSONString(queryOfsSoSaleOutVo));
        SaleOutReturnMessageDto saleOutReturnMessageDto = (SaleOutReturnMessageDto) ofsUnifiedService.unified(interfaceParamDto);
        if (saleOutReturnMessageDto != null) {
            if ("false".equals(saleOutReturnMessageDto.getError()) && "0".equals(saleOutReturnMessageDto.getCode()) && "Success".equals(saleOutReturnMessageDto.getMsg())) {
                List<HeaderDetailsDto> headerDetailsDtoList1 = saleOutReturnMessageDto.getData();
                if (headerDetailsDtoList1 != null && headerDetailsDtoList1.size() > 0) {
                    headerDetailsDtoList.addAll(headerDetailsDtoList1);

                    //TODO OFS没有提供分页字段
                }
            } else {
                //2024年7月30日 13:47:04 查询失败
                logger.error("查询失败，失败原因:{}", JSON.toJSON(saleOutReturnMessageDto));
            }
        } else {
            logger.error("returnMessageBasics为空！queryOfsSoSaleOutVo对象结果：{}", JSON.toJSON(queryOfsSoSaleOutVo));
        }
    }

    /**
     * OFS入库单查询
     *
     * @param queryOfsSoSaleOutVo  接口入参
     * @param headerDetailsDtoList 收集对象
     * @param pageNo               从第几页开始查询
     * @param api                  api接口名称
     * @author liuyang
     */
    public void queryOfsReturnGoods(QueryOfsSoSaleOutVo queryOfsSoSaleOutVo, List<StockinOrderSearchResponse.StockinOrder> headerDetailsDtoList, Long pageNo, String api) throws Exception {
        Assert.notNull(queryOfsSoSaleOutVo, "queryOfsSoSaleOutVo不能为空！");
        Assert.notNull(headerDetailsDtoList, "headerDetailsDtoList不能为空");
        Assert.notNull(pageNo, "pageNo不能为空");
        Assert.notNull(api, "api不能为空");

        Long pageSize = 200L;
        queryOfsSoSaleOutVo.setPageNo(pageNo);
        queryOfsSoSaleOutVo.setPageSize(pageSize);

        InterfaceParamDto interfaceParamDto = new InterfaceParamDto();
        interfaceParamDto.setApi(api);
        interfaceParamDto.setData(JSON.toJSONString(queryOfsSoSaleOutVo));
        StockinOrderSearchResponse rertunGoodsRootBean = (StockinOrderSearchResponse) ofsUnifiedService.unified(interfaceParamDto);
        if (rertunGoodsRootBean != null) {
            if ("false".equals(rertunGoodsRootBean.getError()) && "0".equals(rertunGoodsRootBean.getCode()) && "Success".equals(rertunGoodsRootBean.getMsg())) {
                List<StockinOrderSearchResponse.StockinOrder> stockinOrderList = rertunGoodsRootBean.getData();
                if (stockinOrderList != null && stockinOrderList.size() > 0) {
                    headerDetailsDtoList.addAll(stockinOrderList);

                    //TODO OFS没有提供分页字段，等待开发
                }
            } else {
                logger.error("查询失败，失败原因:{}", JSON.toJSON(interfaceParamDto));
            }
        } else {
            logger.error("rertunGoodsRootBean为空！interfaceParamDto对象的结果集json：{}", JSON.toJSON(interfaceParamDto));
        }
    }

    /**
     * OFS采退订单查询
     *
     * @author liuyang
     */
    public void queryPurchaseReturnOrder(QueryOfsSoSaleOutVo queryOfsSoSaleOutVo, List<PurchaseReturnOrder> headerDetailsDtoList, Long pageNo, String api) throws Exception {
        Assert.notNull(queryOfsSoSaleOutVo, "queryOfsSoSaleOutVo不能为空!");
        Assert.notNull(headerDetailsDtoList, "headerDetailsDtoList不能为空!");
        Assert.notNull(pageNo, "pageNo不能为空!");
        Assert.notNull(api, "api不能为空!");

        Long pageSize = 200L;
        queryOfsSoSaleOutVo.setPageNo(pageNo);
        queryOfsSoSaleOutVo.setPageSize(pageSize);

        InterfaceParamDto interfaceParamDto = new InterfaceParamDto();
        interfaceParamDto.setApi(api);
        interfaceParamDto.setData(JSON.toJSONString(queryOfsSoSaleOutVo));
        PurchaseReturnOrderBean purchaseReturnOrderBean = (PurchaseReturnOrderBean) ofsUnifiedService.unified(interfaceParamDto);
        if (purchaseReturnOrderBean != null) {
            if ("false".equals(purchaseReturnOrderBean.getError()) && "0".equals(purchaseReturnOrderBean.getCode()) && "Success".equals(purchaseReturnOrderBean.getMsg())) {
                List<PurchaseReturnOrder> purchaseReturnOrders = purchaseReturnOrderBean.getData();
                if (purchaseReturnOrders != null && purchaseReturnOrders.size() > 0) {
                    headerDetailsDtoList.addAll(purchaseReturnOrders);

                    //TODO OFS没有提供分页字段，等待开发
                }
            } else {
                logger.error("查询失败，失败原因:{}", JSON.toJSON(interfaceParamDto));
            }
        } else {
            logger.error("purchaseReturnOrderBean为空！interfaceParamDto对象的结果集json：{}", JSON.toJSON(interfaceParamDto));
        }
    }
}
